@@ -18,6 +18,7 @@
 
 #include <stdint.h>
 #include <stddef.h>
+#include <stdlib.h>
 #include <math.h>
 #include <float.h>
 #include <stdbool.h>
@@ -44,16 +45,16 @@
 
 #ifndef CGLM_USE_DEFAULT_EPSILON
 #  ifndef GLM_FLT_EPSILON
-#    define GLM_FLT_EPSILON 1e-5
+#    define GLM_FLT_EPSILON 1e-5f
 #  endif
 #else
 #  define GLM_FLT_EPSILON FLT_EPSILON
 #endif
 
 /*
- * Clip control: define GLM_FORCE_DEPTH_ZERO_TO_ONE before including
+ * Clip control: define CGLM_FORCE_DEPTH_ZERO_TO_ONE before including
  * CGLM to use a clip space between 0 to 1.
- * Coordinate system: define GLM_FORCE_LEFT_HANDED before including
+ * Coordinate system: define CGLM_FORCE_LEFT_HANDED before including
  * CGLM to use the left handed coordinate system by default.
  */
 
